// src/lib/MultiSelect/MultiSelect.jsx
import { Component } from "preact";

// src/lib/preact-listbox-keyboard-navigation/ListboxKeyNav.jsx
import { createElement } from "preact";
function ListboxKeyNav({ tag, keyEvents = {}, children, className, otherProps }) {
  const onKeyDown = (e) => {
    switch (e.keyCode) {
      case 35:
        if (keyEvents.end)
          keyEvents.end(e);
        break;
      case 36:
        if (keyEvents.home)
          keyEvents.home(e);
        break;
      case 38:
        if (keyEvents.up)
          keyEvents.up(e);
        break;
      case 40:
        if (keyEvents.down)
          keyEvents.down(e);
        break;
      default:
        return;
    }
  };
  return createElement(
    tag,
    {
      className,
      onKeyDown,
      ...otherProps
    },
    children
  );
}
var ListboxKeyNav_default = ListboxKeyNav;

// src/lib/MultiSelect/MultiSelectBadge.jsx
import { Fragment, jsx, jsxs } from "preact/jsx-runtime";
var MultiSelectBadge = ({ text, quantity }) => /* @__PURE__ */ jsxs(Fragment, {
  children: [
    text,
    " ",
    /* @__PURE__ */ jsx("span", {
      className: "PreactMultiSelect-badge",
      children: quantity
    })
  ]
});
var MultiSelectBadge_default = MultiSelectBadge;

// src/lib/MultiSelect/MultiSelectDropdown.jsx
import { jsx as jsx2 } from "preact/jsx-runtime";
var MultiSelectDropdown = ({ text, toggleDropdown, quantity, isOpened }) => /* @__PURE__ */ jsx2("button", {
  className: `PreactMultiSelect-dropdownButton${isOpened ? " PreactMultiSelect-dropdownButton--opened" : ""}`,
  onClick: toggleDropdown,
  "aria-haspopup": "true",
  children: /* @__PURE__ */ jsx2(MultiSelectBadge_default, {
    className: "PreactMultiSelect-badge",
    text,
    quantity
  })
});
var MultiSelectDropdown_default = MultiSelectDropdown;

// src/lib/MultiSelect/MultiSelectListButtons.jsx
import { jsx as jsx3, jsxs as jsxs2 } from "preact/jsx-runtime";
var MultiSelectListButtons = ({ selectAll, selectAllButtonText, resetSelections, resetButtonText }) => /* @__PURE__ */ jsxs2("div", {
  className: "PreactMultiSelect-listButtonsWrapper",
  children: [
    /* @__PURE__ */ jsx3("button", {
      className: "PreactMultiSelect-listButtonsSelectAll",
      onClick: selectAll,
      children: selectAllButtonText
    }),
    /* @__PURE__ */ jsx3("button", {
      className: "PreactMultiSelect-listButtonsReset",
      onClick: resetSelections,
      children: resetButtonText
    })
  ]
});
MultiSelectListButtons.defaultProps = {
  selectAllButtonText: "Select All",
  resetButtonText: "Reset"
};
var MultiSelectListButtons_default = MultiSelectListButtons;

// src/lib/MultiSelect/MultiSelectListItem.jsx
import { jsx as jsx4, jsxs as jsxs3 } from "preact/jsx-runtime";
var MultiSelectListItem = (props) => {
  const { label, name, id, handleInputChange, checked, forwardRef } = props;
  return /* @__PURE__ */ jsx4("li", {
    className: "PreactMultiSelect-listItem",
    role: "option",
    children: /* @__PURE__ */ jsxs3("label", {
      role: "checkbox",
      "aria-checked": checked,
      tabIndex: "0",
      htmlFor: id,
      onKeyPress: handleInputChange,
      ref: forwardRef,
      className: `PreactMultiSelect-listItemLabel${checked ? " PreactMultiSelect-listItemLabel--checked" : ""}`,
      children: [
        label,
        /* @__PURE__ */ jsx4("input", {
          className: "PreactMultiSelect-listItemCheckbox",
          type: "checkbox",
          name,
          id,
          onChange: handleInputChange,
          checked
        })
      ]
    })
  });
};
var MultiSelectListItem_default = MultiSelectListItem;

// src/lib/MultiSelect/MultiSelectFooter.jsx
import { jsx as jsx5 } from "preact/jsx-runtime";
var MultiSelectFooter = ({ applyButtonText = "Apply", handleApplyClick }) => /* @__PURE__ */ jsx5("div", {
  className: "PreactMultiSelect-footer",
  children: /* @__PURE__ */ jsx5("button", {
    className: "PreactMultiSelect-footerApplyButton",
    onClick: handleApplyClick,
    children: applyButtonText
  })
});
var MultiSelectFooter_default = MultiSelectFooter;

// src/lib/MultiSelect/multiSelectHandler.js
var getInitialCheckedItems = (list) => list.reduce((acc, listItem) => {
  acc[listItem.id] = listItem.checked;
  return acc;
}, {});
var getMultiSelectHandlers = ({ isDropdownOpened, setIsDropdownOpened, checkedItems, setCheckedItems }) => {
  const toggleDropdown = () => {
    setIsDropdownOpened(!isDropdownOpened);
  };
  const selectAll = () => {
    setCheckedItems(
      Object.keys(checkedItems).reduce((acc, listItemId) => {
        acc[listItemId] = true;
        return acc;
      }, {})
    );
  };
  const resetSelections = () => {
    setCheckedItems(
      Object.keys(checkedItems).reduce((acc, listItemName) => {
        acc[listItemName] = false;
        return acc;
      }, {})
    );
  };
  const handleInputChange = (event) => {
    const tag = event.target.tagName;
    const target = tag === "LABEL" ? event.target.children[0] : event.target;
    if (tag === "LABEL") {
      target.checked = !target.checked;
      event.preventDefault();
    }
    const { id, checked } = target;
    setCheckedItems({ ...checkedItems, [id]: checked });
  };
  return {
    toggleDropdown,
    selectAll,
    resetSelections,
    handleInputChange
  };
};
var multiSelectHandler_default = getMultiSelectHandlers;

// src/lib/MultiSelect/MultiSelect.jsx
import { jsx as jsx6, jsxs as jsxs4 } from "preact/jsx-runtime";
var MultiSelect = class extends Component {
  constructor(props) {
    super(props);
    this.setIsDropdownOpened = this.setIsDropdownOpened.bind(this);
    this.setCheckedItems = this.setCheckedItems.bind(this);
    this.listItems = [];
    this.state = {
      isDropdownOpened: false,
      checkedItems: getInitialCheckedItems(this.props.list || [])
    };
  }
  setIsDropdownOpened(value) {
    this.setState({ isDropdownOpened: value });
  }
  setCheckedItems(value) {
    this.setState({ checkedItems: value });
  }
  onUpdate(prevProps, prevState) {
    const { onOptionChanged } = this.props;
    const { isDropdownOpened, checkedItems } = this.state;
    if (isDropdownOpened && this.listItems[0] && (!prevState || isDropdownOpened !== prevState.isDropdownOpened)) {
      this.listItems[0].focus();
    }
    if (onOptionChanged && (!prevState || checkedItems !== prevState.checkedItems)) {
      onOptionChanged(checkedItems);
    }
  }
  componentDidMount() {
    this.onUpdate();
  }
  componentDidUpdate(prevProps, prevState) {
    this.onUpdate(prevProps, prevState);
  }
  render() {
    const {
      list,
      dropdownButtonText,
      isRightAligned,
      selectAllButtonText,
      onSelectionApplied,
      resetButtonText,
      applyButtonText
    } = this.props;
    const { isDropdownOpened, checkedItems } = this.state;
    const { toggleDropdown, selectAll, resetSelections, handleInputChange } = multiSelectHandler_default({
      isDropdownOpened,
      setIsDropdownOpened: this.setIsDropdownOpened,
      checkedItems,
      setCheckedItems: this.setCheckedItems
    });
    this.listItems = [];
    const keyEvents = {
      up: () => {
        const activeElementIndex = this.listItems.findIndex((item) => item === document.activeElement);
        this.listItems[activeElementIndex - 1] && this.listItems[activeElementIndex - 1].focus();
      },
      down: () => {
        const activeElementIndex = this.listItems.findIndex((item) => item === document.activeElement);
        this.listItems[activeElementIndex + 1] && this.listItems[activeElementIndex + 1].focus();
      },
      home: () => {
        this.listItems[0] && this.listItems[0].focus();
      },
      end: () => {
        this.listItems[this.listItems.length - 1] && this.listItems[this.listItems.length - 1].focus();
      }
    };
    const checkedItemsQuantity = Object.keys(checkedItems).filter((itemName) => checkedItems[itemName]).length;
    const handleApplyClick = () => {
      onSelectionApplied(checkedItems);
    };
    return /* @__PURE__ */ jsxs4("div", {
      className: "PreactMultiSelect-wrapper",
      children: [
        /* @__PURE__ */ jsx6(MultiSelectDropdown_default, {
          text: dropdownButtonText,
          quantity: checkedItemsQuantity,
          toggleDropdown,
          isOpened: isDropdownOpened
        }),
        isDropdownOpened && /* @__PURE__ */ jsxs4("div", {
          className: `PreactMultiSelect-sectionWrapper${isRightAligned ? " PreactMultiSelect-sectionWrapper--rightAligned" : ""}`,
          children: [
            /* @__PURE__ */ jsx6(MultiSelectListButtons_default, {
              selectAll,
              selectAllButtonText,
              resetSelections,
              resetButtonText
            }),
            /* @__PURE__ */ jsx6(ListboxKeyNav_default, {
              role: "listbox",
              tag: "ul",
              className: `PreactMultiSelect-list${onSelectionApplied ? " PreactMultiSelect-list--hasFooter" : ""}`,
              keyEvents: { ...keyEvents },
              children: list.map((listItem, index) => {
                const { label, id, name } = listItem;
                const checked = checkedItems[id];
                const key = `${id}-${index}`;
                return /* @__PURE__ */ jsx6(MultiSelectListItem_default, {
                  className: "multiselect-list-item",
                  label,
                  id,
                  name,
                  handleInputChange,
                  checked,
                  forwardRef: (el) => {
                    this.listItems[index] = el;
                    return el;
                  }
                }, key);
              })
            }),
            onSelectionApplied && /* @__PURE__ */ jsx6(MultiSelectFooter_default, {
              applyButtonText,
              handleApplyClick
            })
          ]
        })
      ]
    });
  }
};
var MultiSelect_default = MultiSelect;
export {
  MultiSelect_default as default
};
